Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1428)

Unified Diff: chrome/browser/tab_contents/tab_contents.cc

Issue 164383: Renames the NavigationEntry::display_url() to virtual_url().... (Closed) Base URL: http://src.chromium.org/svn/trunk/src/
Patch Set: '' Created 11 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/tab_contents/tab_contents.h ('k') | chrome/browser/toolbar_model.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/tab_contents/tab_contents.cc
===================================================================
--- chrome/browser/tab_contents/tab_contents.cc (revision 23341)
+++ chrome/browser/tab_contents/tab_contents.cc (working copy)
@@ -434,7 +434,7 @@
const GURL& TabContents::GetURL() const {
// We may not have a navigation entry yet
NavigationEntry* entry = controller_.GetActiveEntry();
- return entry ? entry->display_url() : GURL::EmptyGURL();
+ return entry ? entry->virtual_url() : GURL::EmptyGURL();
}
const string16& TabContents::GetTitle() const {
@@ -1353,7 +1353,7 @@
}
void TabContents::UpdateHistoryForNavigation(
- const GURL& display_url,
+ const GURL& virtual_url,
const NavigationController::LoadCommittedDetails& details,
const ViewHostMsg_FrameNavigate_Params& params) {
if (profile()->IsOffTheRecord())
@@ -1363,17 +1363,17 @@
HistoryService* hs = profile()->GetHistoryService(Profile::IMPLICIT_ACCESS);
if (hs) {
if (PageTransition::IsMainFrame(params.transition) &&
- display_url != params.url) {
- // Hack on the "display" URL so that it will appear in history. For some
+ virtual_url != params.url) {
+ // Hack on the "virtual" URL so that it will appear in history. For some
// types of URLs, we will display a magic URL that is different from where
// the page is actually navigated. We want the user to see in history
// what they saw in the URL bar, so we add the display URL as a redirect.
// This only applies to the main frame, as the display URL doesn't apply
// to sub-frames.
std::vector<GURL> redirects = params.redirects;
if (!redirects.empty())
- redirects.back() = display_url;
- hs->AddPage(display_url, this, params.page_id, params.referrer,
+ redirects.back() = virtual_url;
+ hs->AddPage(virtual_url, this, params.page_id, params.referrer,
params.transition, redirects, details.did_replace_entry);
} else {
hs->AddPage(params.url, this, params.page_id, params.referrer,
@@ -1408,7 +1408,7 @@
HistoryService* hs =
profile()->GetHistoryService(Profile::IMPLICIT_ACCESS);
if (hs)
- hs->SetPageTitle(entry->display_url(), final_title);
+ hs->SetPageTitle(entry->virtual_url(), final_title);
// Don't allow the title to be saved again for explicitly set ones.
received_page_title_ = explicit_set;
@@ -2000,7 +2000,7 @@
base::TimeDelta elapsed = base::TimeTicks::Now() - current_load_start_;
details.reset(new LoadNotificationDetails(
- entry->display_url(),
+ entry->virtual_url(),
entry->transition_type(),
elapsed,
&controller_,
@@ -1363,17 +1363,17 @@
// types of URLs, we will display a magic URL that is different from where
// the page is actually navigated. We want the user to see in history
- // what they saw in the URL bar, so we add the display URL as a redirect.
- // This only applies to the main frame, as the display URL doesn't apply
+ // what they saw in the URL bar, so we add the virtual URL as a redirect.
+ // This only applies to the main frame, as the virtual URL doesn't apply
// to sub-frames.
std::vector<GURL> redirects = params.redirects;
« no previous file with comments | « chrome/browser/tab_contents/tab_contents.h ('k') | chrome/browser/toolbar_model.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698